@@ -6,10 +6,10 @@
 """
 Contains handlers for the Mito API
 """
-from ast import Call
 from queue import Queue
 from threading import Thread
 from typing import Any, Callable, Dict, List, NoReturn, Union
+from mitosheet.api.get_params import get_params
 from mitosheet.api.get_column_describe import get_column_describe
 from mitosheet.api.get_datafiles import get_datafiles
 from mitosheet.api.get_dataframe_as_csv import get_dataframe_as_csv
@@ -17,11 +17,10 @@ from mitosheet.api.get_dataframe_as_excel import get_dataframe_as_excel
 from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
 from mitosheet.api.get_path_contents import get_path_contents
 from mitosheet.api.get_path_join import get_path_join
-from mitosheet.api.get_pivot_params import get_pivot_params
 from mitosheet.api.get_search_matches import get_search_matches
 from mitosheet.api.get_unique_value_counts import get_unique_value_counts
-from mitosheet.api.graph import get_graph
-from mitosheet.mito_analytics import log_event_processed
+from mitosheet.api.get_column_summary_graph import get_column_summary_graph
+from mitosheet.telemetry.telemetry_utils import log_event_processed
 from mitosheet.steps_manager import StepsManager
 
 # As the column summary statistics tab does three calls, we defaulted to this max
@@ -114,28 +113,29 @@ def handle_api_event(
     so that the frontend knows how to match the responses.
     """
     result: Union[str, List[str]]
+    params = event['params']
     if event["type"] == "datafiles":
-        result = get_datafiles(event)
+        result = get_datafiles(params)
     elif event["type"] == "get_path_contents":
-        result = get_path_contents(event)
+        result = get_path_contents(params)
     elif event["type"] == "get_path_join":
-        result = get_path_join(event)
+        result = get_path_join(params)
     elif event["type"] == "get_dataframe_as_csv":
-        result = get_dataframe_as_csv(event, steps_manager)
-    elif event["type"] == "get_graph":
-        result = get_graph(event, steps_manager)
+        result = get_dataframe_as_csv(params, steps_manager)
+    elif event["type"] == "get_column_summary_graph":
+        result = get_column_summary_graph(params, steps_manager)
     elif event["type"] == "get_column_describe":
-        result = get_column_describe(event, steps_manager)
-    elif event["type"] == "get_pivot_params":
-        result = get_pivot_params(event, steps_manager)
+        result = get_column_describe(params, steps_manager)
+    elif event["type"] == "get_params":
+        result = get_params(params, steps_manager)
     elif event["type"] == "get_excel_file_metadata":
-        result = get_excel_file_metadata(event, steps_manager)
+        result = get_excel_file_metadata(params, steps_manager)
     elif event["type"] == "get_unique_value_counts":
-        result = get_unique_value_counts(event, steps_manager)
+        result = get_unique_value_counts(params, steps_manager)
     elif event["type"] == "get_search_matches":
-        result = get_search_matches(event, steps_manager)
+        result = get_search_matches(params, steps_manager)
     elif event["type"] == "get_dataframe_as_excel":
-        result = get_dataframe_as_excel(event, steps_manager)
+        result = get_dataframe_as_excel(params, steps_manager)
     else:
         raise Exception(f"Event: {event} is not a valid API call")
 
